package com.your_domain.your_product.main;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;

import com.jdbaccess.da.DAFactory;
import com.jdbaccess.da.Transaction;
import com.jdbaccess.db.JDBaccess;
import com.jdbaccess.exception.ApplicationException;
import com.your_domain.your_product.address.dao.AddressDao;
import com.your_domain.your_product.address.dao.AddressDaoImpl;
import com.your_domain.your_product.address.transfer.Address;
import com.your_domain.your_product.employee.dao.EmpAddrDao;
import com.your_domain.your_product.employee.dao.EmpAddrDaoImpl;
import com.your_domain.your_product.employee.dao.EmployeeDao;
import com.your_domain.your_product.employee.dao.EmployeeDaoImpl;
import com.your_domain.your_product.employee.gui.EmployeesFrame;
import com.your_domain.your_product.employee.transfer.EmpAddr;
import com.your_domain.your_product.employee.transfer.Employee;

/**
 * Little GUI-Example for maintaining employees 
 */
public class ExampleGui {
  private static ExampleDA exampleDA;
  
  public static void main (String args []) {
    try {
      ExampleJDBAccess jdbAccess = new ExampleJDBAccess();
      jdbAccess.setDebugMode(false);
      jdbAccess.start();

      exampleDA = new ExampleDA();
      exampleDA.createOrReplace();
      
      ExampleGui exampleGui = new ExampleGui();
      exampleGui.insert();
      new EmployeesFrame(jdbAccess);
      
    } catch (ApplicationException e) {
      System.out.println(e.toString());
    }
  }
  
  private void insert() {
    try {
      Transaction t = DAFactory.getTransaction();
      t.begin();
      EmployeeDao empDao = new EmployeeDaoImpl(t);
      AddressDao addrDao = new AddressDaoImpl(t);
      EmpAddrDao empAddrDao = new EmpAddrDaoImpl(t);
      byte[] picture = getExampleBytes(); // example logo bytes
      int size = 125; // number of employees to create
      // create employees with one address
      Date now = new Date();
      ArrayList empDaos = new ArrayList();
      ArrayList addrDaos = new ArrayList();
      ArrayList empAddrDaos = new ArrayList();
      for (int i=1; i<=size; i++) {
        Long id = new Long(i);
        String empName = "Name" + id.toString();
        Employee emp = new Employee();
        emp.setValueModified("name", empName);
        emp.setValueModified("salary", new BigDecimal(i));
        emp.setValueModified("description", "description " + id); // clob value
        emp.setValueModified("picture", picture);
        emp.setValueModified("creation", now);
        emp.setValueModified("modification", now);
        empDaos.add(emp);
        Address addr = new Address();
        addr.setValueModified("street", "Street" + id);
        addr.setValueModified("streetNumber", id.toString());
        addr.setValueModified("country", "US");
        addr.setValueModified("zipCode", "1000" + id);
        addr.setValueModified("city", "New York");
        addr.setValueModified("creation", now);
        addr.setValueModified("modification", now);
        addrDaos.add(addr);
      }
      ArrayList newEmpDaos = empDao.insert(empDaos); 
      ArrayList newAddrDaos = addrDao.insert(addrDaos);
      for (int i=0; i<newEmpDaos.size(); i++) {
         Employee newEmpDao = (Employee) newEmpDaos.get(i);
         Long newEmpDaoId = newEmpDao.getId();
         Address newAddrDao = (Address) newAddrDaos.get(i);
         Long newAddrDaoId = newAddrDao.getId();
         EmpAddr newEmpAddrDao = new EmpAddr();
         newEmpAddrDao.setValueModified("empId", newEmpDaoId);
         newEmpAddrDao.setValueModified("addrId", newAddrDaoId);
         newEmpAddrDao.setValueModified("orderId", new Integer(i+1));
         empAddrDaos.add(newEmpAddrDao);
      }
      empAddrDao.insert(empAddrDaos);

      t.commit();
      t.end();
    } catch (ApplicationException e) {
      e.printStackTrace();
    }
  }

  private byte[] getExampleBytes() throws ApplicationException {
    return JDBaccess.getBlueElephantBytes();
  }

}
